@@ -21,9 +21,7 @@ use Scalar::Util;
 use String::CRC32;
 use Storable 0.6 qw(freeze thaw);
 
-our $VERSION = '1.06';
-
-$SIG{CHLD} = 'IGNORE';
+our $VERSION = '1.07';
 
 use constant {
     LOCK_SH      => 1,
@@ -425,6 +423,8 @@ sub spawn {
 
     $opts{mode} = 0666 if ! defined $opts{mode};
 
+    $SIG{CHLD} = 'IGNORE';
+
     _spawn(
         key     => $opts{key},
         mode    => $opts{mode},
@@ -471,6 +471,8 @@ sub unspawn {
 
     $h{__ipc}->{run} = 0;
 
+    $SIG{CHLD} = undef;
+
     sleep 1;
 
     IPC::Shareable->clean_up_all if $destroy;
@@ -845,6 +847,7 @@ sub _shm_key_rand {
     my $key;
 
     do {
+        srand();
         $key = int(rand(1_000_000));
     } while ($used_ids{$key});
 
@@ -1063,6 +1066,10 @@ IPC::Shareable - Use shared memory backed variables across processes
 
     IPC::Shareable->singleton('UNIQUE SCRIPT LOCK STRING');
 
+    # Get the actual IPC::Shareable tied object
+
+    my $knot = tied VARIABLE; # Dereference first if necessary
+
 =head1 DESCRIPTION
 
 IPC::Shareable allows you to tie a variable to shared memory making it
@@ -1223,10 +1230,10 @@ Default: B<storable>
 
 Default values for options are:
 
-    key         => IPC_PRIVATE,
+    key         => IPC_PRIVATE, # 0
     create      => 0,
     exclusive   => 0,
-    mode        => 0,
+    mode        => 0666,
     size        => IPC::Shareable::SHM_BUFSIZ(),
     limit       => 1,
     destroy     => 0,
